SmartAutoSuggestBoxLocalizations class

Properties

hashCode int
The hash code for this object.
no setterinherited
noResultsFound String
No results found
no setter
noResultsFoundHint String
We couldn't find any results matching your search. Please try a different query.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchError String
An error occurred
no setter
searchErrorHint String
Something went wrong while searching. Please try again.
no setter
searchingInServer String
Searching in server...
no setter
searchingInServerHint String
Please wait while we fetch the results from the server.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current SmartAutoSuggestBoxLocalizations
no setter

Constants

delegate → const AppLocalizationDelegate