searchingInServerHint property

String get searchingInServerHint

Please wait while we fetch the results from the server.

Implementation

String get searchingInServerHint {
  return Intl.message(
    'Please wait while we fetch the results from the server.',
    name: 'searchingInServerHint',
    desc: '',
    args: [],
  );
}