smart_auto_suggest_view library

Classes

SmartAutoSuggestController<T>
A controller for SmartAutoSuggestBox and SmartAutoSuggestView that provides access to the text input and the currently selected item.
SmartAutoSuggestDataSource<T>
A stateful data source for SmartAutoSuggestBox, SmartAutoSuggestView, and SmartAutoSuggestMultiSelectBox.
SmartAutoSuggestHighlightText
A widget that highlights the matching portion of text based on query.
SmartAutoSuggestItem<T>
An item used in SmartAutoSuggestBox and SmartAutoSuggestView.
SmartAutoSuggestMultiSelectController<T>
A controller for SmartAutoSuggestMultiSelectBox that manages the text input and the set of currently selected items.
SmartAutoSuggestView<T>
A widget that shows a TextField and, directly below it in the normal widget tree, an inline suggestion list.
SmartAutoSuggestViewState<T>

Constants

kComboBoxItemHeight → const double
kComboBoxRadius → const Radius
kOneLineTileHeight → const double
kPickerDiameterRatio → const double
kPickerHeight → const double
kSmartAutoSuggestBoxPopupMaxHeight → const double
The default max height the auto suggest box popup can have

Properties

isDesktopPlatform bool
Whether the current platform is a desktop platform (Windows, macOS, Linux).
no setter