showListWhenEmpty property

bool showListWhenEmpty
final

Whether to show the list when the text field is empty.

When true (default) the list is always visible (showing all items). When false the list is hidden until the user starts typing.

Implementation

final bool showListWhenEmpty;