smart_auto_suggest_view library
Classes
-
SmartAutoSuggestController<
T> - A controller for SmartAutoSuggestBox and SmartAutoSuggestView that provides access to the text input and the currently selected item.
-
SmartAutoSuggestDataSource<
T> - A stateful data source for SmartAutoSuggestBox, SmartAutoSuggestView, and SmartAutoSuggestMultiSelectBox.
- SmartAutoSuggestHighlightText
- A widget that highlights the matching portion of text based on query.
-
SmartAutoSuggestItem<
T> - An item used in SmartAutoSuggestBox and SmartAutoSuggestView.
-
SmartAutoSuggestMultiSelectController<
T> - A controller for SmartAutoSuggestMultiSelectBox that manages the text input and the set of currently selected items.
-
SmartAutoSuggestView<
T> - A widget that shows a TextField and, directly below it in the normal widget tree, an inline suggestion list.
-
SmartAutoSuggestViewState<
T>
Enums
- FluentTextChangedReason
- SmartAutoSuggestBoxDirection
- SmartAutoSuggestSearchMode
- Controls when SmartAutoSuggestDataSource.onSearch is invoked.
Constants
- kComboBoxItemHeight → const double
- kComboBoxRadius → const Radius
- kOneLineTileHeight → const double
- kPickerDiameterRatio → const double
- kPickerHeight → const double
- kSmartAutoSuggestBoxPopupMaxHeight → const double
- The default max height the auto suggest box popup can have
Properties
- isDesktopPlatform → bool
-
Whether the current platform is a desktop platform (Windows, macOS, Linux).
no setter
Typedefs
-
OnChangeSmartAutoSuggestBox<
T> = void Function(String text, FluentTextChangedReason reason) -
SmartAutoSuggestBoxDataSource<
T> = SmartAutoSuggestDataSource< T> - Deprecated. Use SmartAutoSuggestDataSource instead.
-
SmartAutoSuggestBoxItem<
T> = SmartAutoSuggestItem< T> - Deprecated. Use SmartAutoSuggestItem instead.
-
SmartAutoSuggestBoxItemBuilder<
T> = SmartAutoSuggestItemBuilder< T> - Deprecated. Use SmartAutoSuggestItemBuilder instead.
- SmartAutoSuggestBoxSearchMode = SmartAutoSuggestSearchMode
- Deprecated. Use SmartAutoSuggestSearchMode instead.
-
SmartAutoSuggestBoxSorter<
T> = SmartAutoSuggestSorter< T> - Deprecated. Use SmartAutoSuggestSorter instead.
-
SmartAutoSuggestItemBuilder<
T> = Widget Function(BuildContext context, SmartAutoSuggestItem< T> item) -
SmartAutoSuggestSorter<
T> = Set< SmartAutoSuggestItem< Function(String text, Set<T> >SmartAutoSuggestItem< items)T> > - WidgetOrNullBuilder = Widget? Function(BuildContext context)